@@ -1,3 +1,6 @@
+#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
+
 import luigi
 
 from servicecatalog_puppet import constants
@@ -14,3 +17,7 @@ class CodeBuildRunBaseTask(get_ssm_param_task.PuppetTaskWithParameters):
     @property
     def item_name(self):
         return self.code_build_run_name
+
+    @property
+    def item_identifier(self):
+        return "code_build_run_name"
