@@ -1,3 +1,6 @@
+#  Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#  SPDX-License-Identifier: Apache-2.0
+
 import os
 
 import luigi
@@ -21,6 +24,13 @@ class RunDeployInSpokeTask(tasks.PuppetTask):
             "cache_invalidator": self.cache_invalidator,
         }
 
+    def api_calls_used(self):
+        return {
+            f"s3.put_object_{self.puppet_account_id}": 1,
+            f"s3.generate_presigned_url_{self.puppet_account_id}": 1,
+            f"codebuild.start_build_{self.account_id}": 1,
+        }
+
     def requires(self):
         return dict(
             shares=generate_shares_task.GenerateSharesTask(
